pub struct Color(pub f32, pub f32, pub f32, pub f32);Expand description
A color value consisting of four floating point values for the color channels red, green, blue and alpha.
Various drawing methods accept color instances to be used as multiplicators in the drawing
process, e.g. Sprite::draw() allows multiplying the sprite-
texture’s color channels by given color.
Tuple Fields
0: f321: f322: f323: f32Implementations
Sourceimpl Color
impl Color
pub const TRANSPARENT: Color
pub const WHITE: Color
pub const BLACK: Color
pub const RED: Color
pub const GREEN: Color
pub const BLUE: Color
pub const YELLOW: Color
pub const CYAN: Color
pub const MAGENTA: Color
Sourcepub fn alpha(alpha: f32) -> Color
pub fn alpha(alpha: f32) -> Color
Creates a new instance with color channels set to one and the alpha channel set to given value.
Sourcepub fn alpha_mask(alpha: f32) -> Color
pub fn alpha_mask(alpha: f32) -> Color
Creates a new instance with color channels set to zero and the alpha channel set to given value.
Sourcepub fn alpha_pm(alpha: f32) -> Color
pub fn alpha_pm(alpha: f32) -> Color
Creates a new instance with all channels set to given value.
Sourcepub fn lightness(value: f32) -> Color
pub fn lightness(value: f32) -> Color
Creates a new instance with color channels set to given value and the alpha channel set to one.
Sourcepub fn from_hsl(hue: f32, saturation: f32, lightness: f32, alpha: f32) -> Color
pub fn from_hsl(hue: f32, saturation: f32, lightness: f32, alpha: f32) -> Color
Creates a new instance from given HSL (range 0.0 - 1.0)
Sourcepub fn from_temperature(temperature: f32, alpha: f32) -> Color
pub fn from_temperature(temperature: f32, alpha: f32) -> Color
Creates a new instance from given color-temperature (~1000 to ~40000).
Based on http://www.tannerhelland.com/4435/convert-temperature-rgb-algorithm-code/
Sourcepub fn set_g(&mut self, value: f32) -> &mut Color
pub fn set_g(&mut self, value: f32) -> &mut Color
Sets a value for the instance’s green channel.
Sourcepub fn set_b(&mut self, value: f32) -> &mut Color
pub fn set_b(&mut self, value: f32) -> &mut Color
Sets a value for the instance’s blue channel.
Sourcepub fn set_a(&mut self, value: f32) -> &mut Color
pub fn set_a(&mut self, value: f32) -> &mut Color
Sets a value for the instance’s alpha channel.
Sourcepub fn scale(&mut self, scaling: f32) -> &mut Color
pub fn scale(&mut self, scaling: f32) -> &mut Color
Multiplies the instance’s color channels by given scaling factor. Does not modify alpha.
Sourcepub fn scaled(self, scaling: f32) -> Color
pub fn scaled(self, scaling: f32) -> Color
Returns a new Color with color channels multiplied by the given scaling factor. Does not modify alpha.
pub fn to_pm(&self) -> Color